@@ -28,7 +28,7 @@ DEFAULT_PLAYER_ARGS_NO_SUB = ["--speed=1.46"]
 
 
 def fs_actions_usage(action, default_db):
-    return f"""lb {action} [database] [optional args]
+    return f"""library {action} [database] [optional args]
 
     Control playback:
         To stop playback press Ctrl-C in either the terminal or mpv
@@ -37,35 +37,35 @@ def fs_actions_usage(action, default_db):
         echo 'playlist-next force' | socat - /tmp/mpv_socket
 
     If not specified, {action} will try to read {default_db} in the working directory:
-        lb {action}
-        lb {action} ./my/other/database/is-a/db.db
+        library {action}
+        library {action} ./my/other/database/is-a/db.db
 
     Override the default player (mpv):
-        lb does a lot of things to try to automatically use your preferred media player
+        library does a lot of things to try to automatically use your preferred media player
         but if it doesn't guess right you can make it explicit:
-        lb {action} --player "vlc --vlc-opts"
+        library {action} --player "vlc --vlc-opts"
 
     Cast to chromecast groups:
-        lb {action} --cast --cast-to "Office pair"
-        lb {action} -ct "Office pair"  # equivalent
+        library {action} --cast --cast-to "Office pair"
+        library {action} -ct "Office pair"  # equivalent
         If you don't know the exact name of your chromecast group run `catt scan`
 
     Print instead of play:
-        lb {action} --print --limit 10  # print the next 10 files
-        lb {action} -p -L 10  # print the next 10 files
-        lb {action} -p  # this will print _all_ the media. be cautious about `-p` on an unfiltered set
+        library {action} --print --limit 10  # print the next 10 files
+        library {action} -p -L 10  # print the next 10 files
+        library {action} -p  # this will print _all_ the media. be cautious about `-p` on an unfiltered set
 
         Printing modes
-        lb {action} -p    # print in a table
-        lb {action} -p p  # equivalent
-        lb {action} -p a  # print an aggregate report
-        lb {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
+        library {action} -p    # print in a table
+        library {action} -p p  # equivalent
+        library {action} -p a  # print an aggregate report
+        library {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
 
         Check if you have downloaded something before
-        lb {action} -u duration -p -s 'title'
+        library {action} -u duration -p -s 'title'
 
         Print an aggregate report of deleted media
-        lb {action} -w is_deleted=1 -p a
+        library {action} -w is_deleted=1 -p a
         ╒═══════════╤══════════════╤═════════╤═════════╕
         │ path      │ duration     │ size    │   count │
         ╞═══════════╪══════════════╪═════════╪═════════╡
@@ -76,16 +76,16 @@ def fs_actions_usage(action, default_db):
         Total duration: 14 days, 23 hours and 42 minutes
 
         Print an aggregate report of media that has no duration information (likely corrupt media)
-        lb {action} -w 'duration is null' -p a
+        library {action} -w 'duration is null' -p a
 
         Print a list of videos which have below 1280px resolution
-        lb wt -w 'width<1280' -p f
+        library wt -w 'width<1280' -p f
 
         View how much time you have {action}ed
-        lb {action} -w play_count'>'0 -p a
+        library {action} -w play_count'>'0 -p a
 
         See how much video you have
-        lb wt video.db -p a
+        library wt video.db -p a
         ╒═══════════╤═════════╤═════════╤═════════╕
         │ path      │   hours │ size    │   count │
         ╞═══════════╪═════════╪═════════╪═════════╡
@@ -94,10 +94,10 @@ def fs_actions_usage(action, default_db):
         Total duration: 16 years, 7 months, 19 days, 17 hours and 25 minutes
 
         View all the columns
-        lb {action} -p -L 1 --cols '*'
+        library {action} -p -L 1 --cols '*'
 
         Open ipython with all of your media
-        lb {action} -vv -p --cols '*'
+        library {action} -vv -p --cols '*'
         ipdb> len(db_resp)
         462219
 
@@ -107,36 +107,36 @@ def fs_actions_usage(action, default_db):
 
         If you want everything in your play queue you can use the aid of infinity.
         Pick your poison (these all do effectively the same thing):
-        lb {action} -L inf
-        lb {action} -l inf
-        lb {action} --queue inf
-        lb {action} -L 99999999999999999999999
+        library {action} -L inf
+        library {action} -l inf
+        library {action} --queue inf
+        library {action} -L 99999999999999999999999
 
         You may also want to restrict the play queue.
         For example, when you only want 1000 random files:
-        lb {action} -u random -L 1000
+        library {action} -u random -L 1000
 
     Offset the play queue:
         You can also offset the queue. For example if you want to skip one or ten media:
-        lb {action} -S 10  # offset ten from the top of an ordered query
+        library {action} -S 10  # offset ten from the top of an ordered query
 
     Repeat
-        lb {action}                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
-        lb {action} --limit 5        # listen to FIVE songs
-        lb {action} -l inf -u random # listen to random songs indefinitely
-        lb {action} -s infinite      # listen to songs from the band infinite
+        library {action}                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
+        library {action} --limit 5        # listen to FIVE songs
+        library {action} -l inf -u random # listen to random songs indefinitely
+        library {action} -s infinite      # listen to songs from the band infinite
 
     Constrain media by search:
         Audio files have many tags to readily search through so metadata like artist,
         album, and even mood are included in search.
         Video files have less consistent metadata and so only paths are included in search.
-        lb {action} --include happy  # only matches will be included
-        lb {action} -s happy         # equivalent
-        lb {action} --exclude sad   # matches will be excluded
-        lb {action} -E sad          # equivalent
+        library {action} --include happy  # only matches will be included
+        library {action} -s happy         # equivalent
+        library {action} --exclude sad   # matches will be excluded
+        library {action} -E sad          # equivalent
 
         Search only the path column
-        lb {action} -O -s 'path : mad max'
+        library {action} -O -s 'path : mad max'
 
         Double spaces are parsed as one space
         -s '  ost'        # will match OST and not ghost
@@ -144,71 +144,71 @@ def fs_actions_usage(action, default_db):
         -s 'toy  story'    # will match more strictly '/folder/toy story.mp3'
 
     Constrain media by arbitrary SQL expressions:
-        lb {action} --where audio_count = 2  # media which have two audio tracks
-        lb {action} -w "language = 'eng'"    # media which have an English language tag
+        library {action} --where audio_count = 2  # media which have two audio tracks
+        library {action} -w "language = 'eng'"    # media which have an English language tag
                                                (this could be audio _or_ subtitle)
-        lb {action} -w subtitle_count=0      # media that doesn't have subtitles
+        library {action} -w subtitle_count=0      # media that doesn't have subtitles
 
     Constrain media to duration (in minutes):
-        lb {action} --duration 20
-        lb {action} -d 6  # 6 mins ±10 percent (ie. between 5 and 7 mins)
-        lb {action} -d-6  # less than 6 mins
-        lb {action} -d+6  # more than 6 mins
+        library {action} --duration 20
+        library {action} -d 6  # 6 mins ±10 percent (ie. between 5 and 7 mins)
+        library {action} -d-6  # less than 6 mins
+        library {action} -d+6  # more than 6 mins
 
         Duration can be specified multiple times:
-        lb {action} -d+5 -d-7  # should be similar to -d 6
+        library {action} -d+5 -d-7  # should be similar to -d 6
 
         If you want exact time use `where`
-        lb {action} --where 'duration=6*60'
+        library {action} --where 'duration=6*60'
 
     Constrain media to file size (in megabytes):
-        lb {action} --size 20
-        lb {action} -z 6  # 6 MB ±10 percent (ie. between 5 and 7 MB)
-        lb {action} -z-6  # less than 6 MB
-        lb {action} -z+6  # more than 6 MB
+        library {action} --size 20
+        library {action} -z 6  # 6 MB ±10 percent (ie. between 5 and 7 MB)
+        library {action} -z-6  # less than 6 MB
+        library {action} -z+6  # more than 6 MB
 
     Constrain media by throughput:
         Bitrate information is not explicitly saved.
         You can use file size and duration as a proxy for throughput:
-        lb {action} -w 'size/duration<50000'
+        library {action} -w 'size/duration<50000'
 
     Constrain media to portrait orientation video:
-        lb {action} --portrait
-        lb {action} -w 'width<height' # equivalent
+        library {action} --portrait
+        library {action} -w 'width<height' # equivalent
 
     Specify media play order:
-        lb {action} --sort duration   # play shortest media first
-        lb {action} -u duration desc  # play longest media first
+        library {action} --sort duration   # play shortest media first
+        library {action} -u duration desc  # play longest media first
         You can use multiple SQL ORDER BY expressions
-        lb {action} -u subtitle_count > 0 desc # play media that has at least one subtitle first
+        library {action} -u subtitle_count > 0 desc # play media that has at least one subtitle first
 
     Play media in order (similarly named episodes):
-        lb {action} --play-in-order
+        library {action} --play-in-order
         There are multiple strictness levels of --play-in-order.
         If things aren't playing in order try adding more `O`s:
-        lb {action} -O    # normal
-        lb {action} -OO   # slower, more complex algorithm
-        lb {action} -OOO  # strict
+        library {action} -O    # normal
+        library {action} -OO   # slower, more complex algorithm
+        library {action} -OOO  # strict
 
     Post-actions -- choose what to do after playing:
-        lb {action} --post-action delete  # delete file after playing
-        lb {action} -k ask  # ask after each whether to keep or delete
+        library {action} --post-action delete  # delete file after playing
+        library {action} -k ask  # ask after each whether to keep or delete
 
-        lb {action} -k askkeep  # ask after each whether to move to a keep folder or delete
+        library {action} -k askkeep  # ask after each whether to move to a keep folder or delete
         The default location of the keep folder is ./keep/ (relative to the played media file)
         You can change this by explicitly setting an *absolute* `keep-dir` path:
-        lb {action} -k askkeep --keep-dir /home/my/music/keep/
+        library {action} -k askkeep --keep-dir /home/my/music/keep/
 
     Experimental options:
         Duration to play (in seconds) while changing the channel
-        lb {action} --interdimensional-cable 40
-        lb {action} -4dtv 40
+        library {action} --interdimensional-cable 40
+        library {action} -4dtv 40
 """
 
 
 def parse_args(action, default_db, default_chromecast=""):
     parser = argparse.ArgumentParser(
-        prog="lb " + action,
+        prog="library " + action,
         usage=fs_actions_usage(action, default_db),
     )
 
