@@ -3,6 +3,7 @@ import argparse, sys
 import scripts
 from xklb.fs_actions import filesystem, listen, watch
 from xklb.fs_extract import main as fs_add
+from xklb.playback import playback_next, playback_now, playback_stop
 from xklb.subtitle import main as subtitle
 from xklb.tabs_actions import tabs
 from xklb.tabs_extract import tabs_add
@@ -30,6 +31,11 @@ def lb_usage():
       tubewatch [tw, entries]      Watch the tube
       tubelisten [tl]              Listen to the tube
 
+    playback subcommands:
+      now                          Print what is currently playing
+      next                         Play next file
+      stop                         Stop all playback
+
     browser tab subcommands:
       tabsadd                      Create a tabs database; Add URLs
       tabs [tabswatch, tb]         Open your tabs for the day
@@ -70,11 +76,6 @@ def lb(args=None):
     subp_dedupe = subparsers.add_parser("dedupe", add_help=False)
     subp_dedupe.set_defaults(func=scripts.deduplicate_music)
 
-    subp_tabsadd = subparsers.add_parser("tabsadd", add_help=False)
-    subp_tabsadd.set_defaults(func=tabs_add)
-    subp_tabs = subparsers.add_parser("tabs", aliases=["tabswatch", "tb"], add_help=False)
-    subp_tabs.set_defaults(func=tabs)
-
     subp_tubelist = subparsers.add_parser("tubelist", aliases=["playlist", "playlists"], add_help=False)
     subp_tubelist.set_defaults(func=tube_list)
     subp_tubeadd = subparsers.add_parser("tubeadd", aliases=["ta", "xt"], add_help=False)
@@ -87,6 +88,18 @@ def lb(args=None):
     subp_tubelisten = subparsers.add_parser(SC.tubelisten, aliases=["tl"], add_help=False)
     subp_tubelisten.set_defaults(func=tube_listen)
 
+    subp_playback_now = subparsers.add_parser("now", add_help=False)
+    subp_playback_now.set_defaults(func=playback_now)
+    subp_playback_next = subparsers.add_parser("next", add_help=False)
+    subp_playback_next.set_defaults(func=playback_next)
+    subp_playback_stop = subparsers.add_parser("stop", add_help=False)
+    subp_playback_stop.set_defaults(func=playback_stop)
+
+    subp_tabsadd = subparsers.add_parser("tabsadd", add_help=False)
+    subp_tabsadd.set_defaults(func=tabs_add)
+    subp_tabs = subparsers.add_parser("tabs", aliases=["tabswatch", "tb"], add_help=False)
+    subp_tabs.set_defaults(func=tabs)
+
     parser.add_argument("--version", "-V", action="store_true")
     args, _unk = parser.parse_known_args(args)
     if args.version:
